<?php
/**
 * Default theme functions
 *
 * @package Munk
 */
if ( ! function_exists( 'munk_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function munk_setup() {

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );	

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );
	
    // Gutenberg support
	add_theme_support( 'align-wide' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'responsive-embeds' );
    add_theme_support( 'custom-line-height' );
    add_theme_support( 'custom-units', 'rem', 'em' );    
	add_theme_support( 'editor-styles' );
    add_theme_support('experimental-link-color');
	add_editor_style( 'assets/css/editor-style.css' );
	
	add_theme_support( 'gutenberg', array(
		 'wide-images' => true,
	) );	

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	//Custom Image Sizes
	set_post_thumbnail_size( 150, 150, true );
	add_image_size( 'munk-wide', 1200, 450, true );				

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'menu-1' => esc_html__( 'Primary', 'munk' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'munk_custom_background_args', array(
		'default-color' => 'f5f6f7',
	) ) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support( 'custom-logo', array(
		'height'      => 75,
		'width'       => 260,
		'flex-height' => true,
		'flex-width'  => true,
		'header-text' => array( 'site-title', 'site-description' ),				
	) );		

}
endif;
add_action( 'after_setup_theme', 'munk_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function munk_content_width() {
	// phpcs:ignore
	$GLOBALS['content_width'] = apply_filters( 'munk_content_width', 750 );
}
add_action( 'after_setup_theme', 'munk_content_width', 0 );


/**
 * Return Theme options. 
 * wrapper for get_theme_mod
 */
if ( ! function_exists( 'munk_get_option' ) ) {

	/**
	 * Return Theme options.
	 *	 
	 */
	function munk_get_option( $option ) {
		
		$theme_defaults = munk_customizer_defaults();
		$default_value = $theme_defaults[$option];		
		
		return get_theme_mod($option, $default_value );

	}
}